import React, { useEffect, useState } from 'react'
import { Select, Spin } from 'antd'
import request from '@/utils/request'

export default (props) => {
  const [loading, setLoading] = useState(false)
  const [list, setList] = useState([])
  const [value, setValue] = useState()

  const { autoDefault, ...selectProps } = props

  const filterFunc = (input, option) => {
    return option.children.toLowerCase().indexOf(input.toLowerCase()) >= 0
  }

  const handleChange = (val) => {
    setValue(val)
    const school = list.filter((s) => s.schoolId === val)[0]

    props.onChange(val, school)
  }

  useEffect(() => {
    if (props.value !== value) {
      setValue(props.value)
    }
  }, [props.value, value])

  useEffect(() => {
    setLoading(true)
    request('/school', { params: { pageSize: 100 } }).then(res => {
      const records = res.records || []
      setList(records)
      setLoading(false)

      if (autoDefault !== false && records.length > 0) {
        setValue(records[0].schoolId)
        props.onChange(records[0].schoolId, records[0])
      }

    }).catch((e) => {
      // eslint-disable-next-line
      console.error(e.message)
      setLoading(false)
    })

  // eslint-disable-next-line
  }, [])

  return (
    <Spin spinning={loading}>
      <Select
        showSearch
        optionFilterProp="children"
        filterOption={filterFunc}
        {...selectProps}
        value={value}
        onChange={handleChange}
      >
      {
        list.map((s) => (<Select.Option key={s.schoolId} value={s.schoolId}>{s.name}</Select.Option>))
      }
      </Select>
    </Spin>
  )
}
